@@ -7,16 +7,11 @@ import qualified Language.Haskell.TH as Meta
 import Aws.Lambda.Meta.Common
 import qualified Aws.Lambda.Meta.Discover as Discover
 import qualified Aws.Lambda.Meta.Dispatch as Dispatch
+import qualified Aws.Lambda.Meta.Main as Main
 
-{-| Generate the run function
-
-It will create a dispatcher that is a huge @case@ expression that
-expects the name of the handler provided by AWS Lambda, and will
-execute the appropriate user function
- -}
-generate :: Meta.DecQ
-generate = do
+generate :: Main.DispatcherOptions -> Main.DispatcherStrategy -> Meta.DecQ
+generate options strategy = do
   handlers <- Meta.runIO Discover.handlers
   clause' <- getFieldsFrom "LambdaOptions" ["functionHandler", "contextObject", "eventObject", "executionUuid"]
-  body <- Dispatch.generate handlers
+  body <- Dispatch.generate options strategy handlers
   pure $ Meta.FunD (Meta.mkName "run") [Meta.Clause [clause'] (Meta.NormalB body) []]
