@@ -9,7 +9,7 @@ module Aws.Lambda.Runtime.Publish
 
 import Control.Monad (void)
 import Data.Aeson
-import qualified Data.ByteString.Char8 as ByteString
+import qualified Data.Text.Encoding as T
 import qualified Network.HTTP.Client as Http
 
 import qualified Aws.Lambda.Runtime.API.Endpoints as Endpoints
@@ -18,14 +18,14 @@ import Aws.Lambda.Runtime.Context (Context (..))
 import qualified Aws.Lambda.Runtime.Error as Error
 
 -- | Publishes the result back to AWS Lambda
-result :: LambdaResult -> String -> Context -> Http.Manager -> IO ()
+result :: LambdaResult -> String -> Context context -> Http.Manager -> IO ()
 result lambdaResult lambdaApi context manager = do
   let Endpoints.Endpoint endpoint = Endpoints.response lambdaApi (awsRequestId context)
   rawRequest <- Http.parseRequest endpoint
 
   let requestBody = case lambdaResult of
-        (StandaloneLambdaResult res) -> Http.RequestBodyBS (ByteString.pack res)
-        (ApiGatewayResult res) -> Http.RequestBodyLBS (encode res)
+        (StandaloneLambdaResult res) -> Http.RequestBodyBS (T.encodeUtf8 . unLambdaResponseBody $ res)
+        (ApiGatewayResult res)       -> Http.RequestBodyLBS (encode res)
       request = rawRequest
                 { Http.method = "POST"
                 , Http.requestBody = requestBody
@@ -34,22 +34,22 @@ result lambdaResult lambdaApi context manager = do
   void $ Http.httpNoBody request manager
 
 -- | Publishes an invocation error back to AWS Lambda
-invocationError :: Error.Invocation -> String -> Context -> Http.Manager -> IO ()
+invocationError :: Error.Invocation -> String -> Context context -> Http.Manager -> IO ()
 invocationError err lambdaApi context =
   publish err (Endpoints.invocationError lambdaApi $ awsRequestId context) context
 
 -- | Publishes a parsing error back to AWS Lambda
-parsingError :: Error.Parsing -> String -> Context -> Http.Manager -> IO ()
+parsingError :: Error.Parsing -> String -> Context context -> Http.Manager -> IO ()
 parsingError err lambdaApi context =
   publish err (Endpoints.invocationError lambdaApi $ awsRequestId context)
     context
 
 -- | Publishes a runtime initialization error back to AWS Lambda
-runtimeInitError :: ToJSON err => err -> String -> Context -> Http.Manager -> IO ()
+runtimeInitError :: ToJSON err => err -> String -> Context context -> Http.Manager -> IO ()
 runtimeInitError err lambdaApi =
   publish err (Endpoints.runtimeInitError lambdaApi)
 
-publish :: ToJSON err => err -> Endpoints.Endpoint -> Context -> Http.Manager -> IO ()
+publish :: ToJSON err => err -> Endpoints.Endpoint -> Context context -> Http.Manager -> IO ()
 publish err (Endpoints.Endpoint endpoint) Context{..} manager = do
   rawRequest <- Http.parseRequest endpoint
 
